@@ -1,8 +1,9 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.3.2.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
+   Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -40,11 +41,14 @@
    define necessary library symbols; they are noted "INFRINGES ON
    USER NAME SPACE" below.  */
 
+/* Undocumented macros, especially those whose name start with YY_,
+   are private implementation details.  Do not rely on them.  */
+
 /* Identify Bison output.  */
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.4"
+#define YYBISON_VERSION "3.3.2"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -68,8 +72,8 @@
 #define yynerrs         unitsnerrs
 
 
-/* Copy the first part of user declarations.  */
-#line 24 "parse.y" /* yacc.c:339  */
+/* First part of user prologue.  */
+#line 24 "parse.y" /* yacc.c:337  */
 
 #include<stdio.h>
 #include "units.h"
@@ -197,13 +201,16 @@ funcunit(struct unittype *theunit, struct function const *fun)
 
 
 
-#line 201 "parse.tab.c" /* yacc.c:339  */
-
+#line 205 "parse.tab.c" /* yacc.c:337  */
 # ifndef YY_NULLPTR
-#  if defined __cplusplus && 201103L <= __cplusplus
-#   define YY_NULLPTR nullptr
+#  if defined __cplusplus
+#   if 201103L <= __cplusplus
+#    define YY_NULLPTR nullptr
+#   else
+#    define YY_NULLPTR 0
+#   endif
 #  else
-#   define YY_NULLPTR 0
+#   define YY_NULLPTR ((void*)0)
 #  endif
 # endif
 
@@ -267,7 +274,7 @@ extern int unitsdebug;
 
 union UNITSSTYPE
 {
-#line 157 "parse.y" /* yacc.c:355  */
+#line 157 "parse.y" /* yacc.c:352  */
 
   double number;
   int integer;
@@ -275,7 +282,7 @@ union UNITSSTYPE
   struct function *realfunc;
   struct func *unitfunc;
 
-#line 279 "parse.tab.c" /* yacc.c:355  */
+#line 286 "parse.tab.c" /* yacc.c:352  */
 };
 
 typedef union UNITSSTYPE UNITSSTYPE;
@@ -289,9 +296,7 @@ int unitsparse (struct commtype *comm);
 
 
 
-/* Copy the second part of user declarations.  */
 
-#line 295 "parse.tab.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -312,13 +317,13 @@ typedef signed char yytype_int8;
 #ifdef YYTYPE_UINT16
 typedef YYTYPE_UINT16 yytype_uint16;
 #else
-typedef unsigned short int yytype_uint16;
+typedef unsigned short yytype_uint16;
 #endif
 
 #ifdef YYTYPE_INT16
 typedef YYTYPE_INT16 yytype_int16;
 #else
-typedef short int yytype_int16;
+typedef short yytype_int16;
 #endif
 
 #ifndef YYSIZE_T
@@ -330,7 +335,7 @@ typedef short int yytype_int16;
 #  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
 #  define YYSIZE_T size_t
 # else
-#  define YYSIZE_T unsigned int
+#  define YYSIZE_T unsigned
 # endif
 #endif
 
@@ -366,15 +371,6 @@ typedef short int yytype_int16;
 # define YY_ATTRIBUTE_UNUSED YY_ATTRIBUTE ((__unused__))
 #endif
 
-#if !defined _Noreturn \
-     && (!defined __STDC_VERSION__ || __STDC_VERSION__ < 201112)
-# if defined _MSC_VER && 1200 <= _MSC_VER
-#  define _Noreturn __declspec (noreturn)
-# else
-#  define _Noreturn YY_ATTRIBUTE ((__noreturn__))
-# endif
-#endif
-
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
 # define YYUSE(E) ((void) (E))
@@ -382,7 +378,7 @@ typedef short int yytype_int16;
 # define YYUSE(E) /* empty */
 #endif
 
-#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
+#if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
 # define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
     _Pragma ("GCC diagnostic push") \
@@ -544,16 +540,16 @@ union yyalloc
 /* YYNSTATES -- Number of states.  */
 #define YYNSTATES  61
 
-/* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
-   by yylex, with out-of-bounds checking.  */
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   279
 
+/* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
+   as returned by yylex, with out-of-bounds checking.  */
 #define YYTRANSLATE(YYX)                                                \
-  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
+  ((unsigned) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
-   as returned by yylex, without out-of-bounds checking.  */
+   as returned by yylex.  */
 static const yytype_uint8 yytranslate[] =
 {
        0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -762,22 +758,22 @@ static const yytype_uint8 yyr2[] =
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
-#define YYBACKUP(Token, Value)                                  \
-do                                                              \
-  if (yychar == YYEMPTY)                                        \
-    {                                                           \
-      yychar = (Token);                                         \
-      yylval = (Value);                                         \
-      YYPOPSTACK (yylen);                                       \
-      yystate = *yyssp;                                         \
-      goto yybackup;                                            \
-    }                                                           \
-  else                                                          \
-    {                                                           \
-      yyerror (comm, YY_("syntax error: cannot back up")); \
-      YYERROR;                                                  \
-    }                                                           \
-while (0)
+#define YYBACKUP(Token, Value)                                    \
+  do                                                              \
+    if (yychar == YYEMPTY)                                        \
+      {                                                           \
+        yychar = (Token);                                         \
+        yylval = (Value);                                         \
+        YYPOPSTACK (yylen);                                       \
+        yystate = *yyssp;                                         \
+        goto yybackup;                                            \
+      }                                                           \
+    else                                                          \
+      {                                                           \
+        yyerror (comm, YY_("syntax error: cannot back up")); \
+        YYERROR;                                                  \
+      }                                                           \
+  while (0)
 
 /* Error token number */
 #define YYTERROR        1
@@ -817,38 +813,38 @@ do {                                                                      \
 } while (0)
 
 
-/*----------------------------------------.
-| Print this symbol's value on YYOUTPUT.  |
-`----------------------------------------*/
+/*-----------------------------------.
+| Print this symbol's value on YYO.  |
+`-----------------------------------*/
 
 static void
-yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, struct commtype *comm)
+yy_symbol_value_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep, struct commtype *comm)
 {
-  FILE *yyo = yyoutput;
-  YYUSE (yyo);
+  FILE *yyoutput = yyo;
+  YYUSE (yyoutput);
   YYUSE (comm);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
   if (yytype < YYNTOKENS)
-    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+    YYPRINT (yyo, yytoknum[yytype], *yyvaluep);
 # endif
   YYUSE (yytype);
 }
 
 
-/*--------------------------------.
-| Print this symbol on YYOUTPUT.  |
-`--------------------------------*/
+/*---------------------------.
+| Print this symbol on YYO.  |
+`---------------------------*/
 
 static void
-yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, struct commtype *comm)
+yy_symbol_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep, struct commtype *comm)
 {
-  YYFPRINTF (yyoutput, "%s %s (",
+  YYFPRINTF (yyo, "%s %s (",
              yytype < YYNTOKENS ? "token" : "nterm", yytname[yytype]);
 
-  yy_symbol_value_print (yyoutput, yytype, yyvaluep, comm);
-  YYFPRINTF (yyoutput, ")");
+  yy_symbol_value_print (yyo, yytype, yyvaluep, comm);
+  YYFPRINTF (yyo, ")");
 }
 
 /*------------------------------------------------------------------.
@@ -882,7 +878,7 @@ do {                                                            \
 static void
 yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, struct commtype *comm)
 {
-  unsigned long int yylno = yyrline[yyrule];
+  unsigned long yylno = yyrline[yyrule];
   int yynrhs = yyr2[yyrule];
   int yyi;
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
@@ -893,7 +889,7 @@ yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, struct commtyp
       YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr,
                        yystos[yyssp[yyi + 1 - yynrhs]],
-                       &(yyvsp[(yyi + 1) - (yynrhs)])
+                       &yyvsp[(yyi + 1) - (yynrhs)]
                                               , comm);
       YYFPRINTF (stderr, "\n");
     }
@@ -997,7 +993,10 @@ yytnamerr (char *yyres, const char *yystr)
           case '\\':
             if (*++yyp != '\\')
               goto do_not_strip_quotes;
-            /* Fall through.  */
+            else
+              goto append;
+
+          append:
           default:
             if (yyres)
               yyres[yyn] = *yyp;
@@ -1015,7 +1014,7 @@ yytnamerr (char *yyres, const char *yystr)
   if (! yyres)
     return yystrlen (yystr);
 
-  return yystpcpy (yyres, yystr) - yyres;
+  return (YYSIZE_T) (yystpcpy (yyres, yystr) - yyres);
 }
 # endif
 
@@ -1093,10 +1092,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                 yyarg[yycount++] = yytname[yyx];
                 {
                   YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
-                  if (! (yysize <= yysize1
-                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                  if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+                    yysize = yysize1;
+                  else
                     return 2;
-                  yysize = yysize1;
                 }
               }
         }
@@ -1108,6 +1107,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
       case N:                               \
         yyformat = S;                       \
       break
+    default: /* Avoid compiler warnings. */
       YYCASE_(0, YY_("syntax error"));
       YYCASE_(1, YY_("syntax error, unexpected %s"));
       YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
@@ -1119,9 +1119,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 
   {
     YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
-    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+    if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+      yysize = yysize1;
+    else
       return 2;
-    yysize = yysize1;
   }
 
   if (*yymsg_alloc < yysize)
@@ -1171,37 +1172,36 @@ yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep, struct commtype *c
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   switch (yytype)
     {
-          case 4: /* UNIT  */
+    case 4: /* UNIT  */
 #line 191 "parse.y" /* yacc.c:1257  */
       { destroyunit(((*yyvaluep).unit));}
-#line 1178 "parse.tab.c" /* yacc.c:1257  */
+#line 1179 "parse.tab.c" /* yacc.c:1257  */
         break;
 
     case 29: /* unitexpr  */
 #line 191 "parse.y" /* yacc.c:1257  */
       { destroyunit(((*yyvaluep).unit));}
-#line 1184 "parse.tab.c" /* yacc.c:1257  */
+#line 1185 "parse.tab.c" /* yacc.c:1257  */
         break;
 
     case 30: /* expr  */
 #line 191 "parse.y" /* yacc.c:1257  */
       { destroyunit(((*yyvaluep).unit));}
-#line 1190 "parse.tab.c" /* yacc.c:1257  */
+#line 1191 "parse.tab.c" /* yacc.c:1257  */
         break;
 
     case 32: /* pexpr  */
 #line 191 "parse.y" /* yacc.c:1257  */
       { destroyunit(((*yyvaluep).unit));}
-#line 1196 "parse.tab.c" /* yacc.c:1257  */
+#line 1197 "parse.tab.c" /* yacc.c:1257  */
         break;
 
     case 33: /* list  */
 #line 191 "parse.y" /* yacc.c:1257  */
       { destroyunit(((*yyvaluep).unit));}
-#line 1202 "parse.tab.c" /* yacc.c:1257  */
+#line 1203 "parse.tab.c" /* yacc.c:1257  */
         break;
 
-
       default:
         break;
     }
@@ -1287,23 +1287,31 @@ YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);
   yychar = YYEMPTY; /* Cause a token to be read.  */
   goto yysetstate;
 
+
 /*------------------------------------------------------------.
-| yynewstate -- Push a new state, which is found in yystate.  |
+| yynewstate -- push a new state, which is found in yystate.  |
 `------------------------------------------------------------*/
- yynewstate:
+yynewstate:
   /* In all cases, when you get here, the value and location stacks
      have just been pushed.  So pushing a state here evens the stacks.  */
   yyssp++;
 
- yysetstate:
-  *yyssp = yystate;
+
+/*--------------------------------------------------------------------.
+| yynewstate -- set current state (the top of the stack) to yystate.  |
+`--------------------------------------------------------------------*/
+yysetstate:
+  *yyssp = (yytype_int16) yystate;
 
   if (yyss + yystacksize - 1 <= yyssp)
+#if !defined yyoverflow && !defined YYSTACK_RELOCATE
+    goto yyexhaustedlab;
+#else
     {
       /* Get the current used size of the three stacks, in elements.  */
-      YYSIZE_T yysize = yyssp - yyss + 1;
+      YYSIZE_T yysize = (YYSIZE_T) (yyssp - yyss + 1);
 
-#ifdef yyoverflow
+# if defined yyoverflow
       {
         /* Give user a chance to reallocate the stack.  Use copies of
            these so that the &'s don't force the real ones into
@@ -1319,14 +1327,10 @@ YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);
                     &yyss1, yysize * sizeof (*yyssp),
                     &yyvs1, yysize * sizeof (*yyvsp),
                     &yystacksize);
-
         yyss = yyss1;
         yyvs = yyvs1;
       }
-#else /* no yyoverflow */
-# ifndef YYSTACK_RELOCATE
-      goto yyexhaustedlab;
-# else
+# else /* defined YYSTACK_RELOCATE */
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= yystacksize)
         goto yyexhaustedlab;
@@ -1342,22 +1346,22 @@ YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);
           goto yyexhaustedlab;
         YYSTACK_RELOCATE (yyss_alloc, yyss);
         YYSTACK_RELOCATE (yyvs_alloc, yyvs);
-#  undef YYSTACK_RELOCATE
+# undef YYSTACK_RELOCATE
         if (yyss1 != yyssa)
           YYSTACK_FREE (yyss1);
       }
 # endif
-#endif /* no yyoverflow */
 
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
-                  (unsigned long int) yystacksize));
+                  (unsigned long) yystacksize));
 
       if (yyss + yystacksize - 1 <= yyssp)
         YYABORT;
     }
+#endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
@@ -1366,11 +1370,11 @@ YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);
 
   goto yybackup;
 
+
 /*-----------.
 | yybackup.  |
 `-----------*/
 yybackup:
-
   /* Do appropriate processing given the current state.  Read a
      lookahead token if we need one and don't already have one.  */
 
@@ -1443,7 +1447,7 @@ yydefault:
 
 
 /*-----------------------------.
-| yyreduce -- Do a reduction.  |
+| yyreduce -- do a reduction.  |
 `-----------------------------*/
 yyreduce:
   /* yyn is the number of a rule to reduce with.  */
@@ -1464,229 +1468,229 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 203 "parse.y" /* yacc.c:1646  */
+#line 203 "parse.y" /* yacc.c:1652  */
     { comm->result = makenumunit(1,&err); CHECK(0);
                        comm->errorcode = 0; YYACCEPT; }
-#line 1471 "parse.tab.c" /* yacc.c:1646  */
+#line 1475 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 3:
-#line 205 "parse.y" /* yacc.c:1646  */
+#line 205 "parse.y" /* yacc.c:1652  */
     { comm->result = (yyvsp[-1].unit); comm->errorcode = 0; YYACCEPT; }
-#line 1477 "parse.tab.c" /* yacc.c:1646  */
+#line 1481 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 4:
-#line 206 "parse.y" /* yacc.c:1646  */
+#line 206 "parse.y" /* yacc.c:1652  */
     { YYABORT; }
-#line 1483 "parse.tab.c" /* yacc.c:1646  */
+#line 1487 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 5:
-#line 209 "parse.y" /* yacc.c:1646  */
+#line 209 "parse.y" /* yacc.c:1652  */
     { (yyval.unit) = (yyvsp[0].unit);}
-#line 1489 "parse.tab.c" /* yacc.c:1646  */
+#line 1493 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 6:
-#line 210 "parse.y" /* yacc.c:1646  */
+#line 210 "parse.y" /* yacc.c:1652  */
     { invertunit((yyvsp[0].unit)); (yyval.unit)=(yyvsp[0].unit);}
-#line 1495 "parse.tab.c" /* yacc.c:1646  */
+#line 1499 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 7:
-#line 213 "parse.y" /* yacc.c:1646  */
+#line 213 "parse.y" /* yacc.c:1652  */
     { (yyval.unit) = (yyvsp[0].unit); }
-#line 1501 "parse.tab.c" /* yacc.c:1646  */
+#line 1505 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 8:
-#line 214 "parse.y" /* yacc.c:1646  */
+#line 214 "parse.y" /* yacc.c:1652  */
     { (yyval.unit) = (yyvsp[0].unit); (yyval.unit)->factor *= -1; }
-#line 1507 "parse.tab.c" /* yacc.c:1646  */
+#line 1511 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 9:
-#line 215 "parse.y" /* yacc.c:1646  */
+#line 215 "parse.y" /* yacc.c:1652  */
     { (yyval.unit) = (yyvsp[0].unit); (yyval.unit)->factor *= -1; }
-#line 1513 "parse.tab.c" /* yacc.c:1646  */
+#line 1517 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 10:
-#line 216 "parse.y" /* yacc.c:1646  */
+#line 216 "parse.y" /* yacc.c:1652  */
     { err = addunit((yyvsp[-2].unit),(yyvsp[0].unit)); destroyunit((yyvsp[0].unit));
                                       CHECK((yyvsp[-2].unit));(yyval.unit)=(yyvsp[-2].unit);}
-#line 1520 "parse.tab.c" /* yacc.c:1646  */
+#line 1524 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 11:
-#line 218 "parse.y" /* yacc.c:1646  */
+#line 218 "parse.y" /* yacc.c:1652  */
     { (yyvsp[0].unit)->factor *= -1;
                                       err = addunit((yyvsp[-2].unit),(yyvsp[0].unit)); destroyunit((yyvsp[0].unit));
                                       CHECK((yyvsp[-2].unit));(yyval.unit)=(yyvsp[-2].unit);}
-#line 1528 "parse.tab.c" /* yacc.c:1646  */
+#line 1532 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 12:
-#line 221 "parse.y" /* yacc.c:1646  */
+#line 221 "parse.y" /* yacc.c:1652  */
     { err = divunit((yyvsp[-2].unit), (yyvsp[0].unit)); destroyunit((yyvsp[0].unit));
                                       CHECK((yyvsp[-2].unit));(yyval.unit)=(yyvsp[-2].unit);}
-#line 1535 "parse.tab.c" /* yacc.c:1646  */
+#line 1539 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 13:
-#line 223 "parse.y" /* yacc.c:1646  */
+#line 223 "parse.y" /* yacc.c:1652  */
     { err = multunit((yyvsp[-2].unit),(yyvsp[0].unit)); destroyunit((yyvsp[0].unit));
                                       CHECK((yyvsp[-2].unit));(yyval.unit)=(yyvsp[-2].unit);}
-#line 1542 "parse.tab.c" /* yacc.c:1646  */
+#line 1546 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 14:
-#line 225 "parse.y" /* yacc.c:1646  */
+#line 225 "parse.y" /* yacc.c:1652  */
     { err = multunit((yyvsp[-2].unit),(yyvsp[0].unit)); destroyunit((yyvsp[0].unit));
                                       CHECK((yyvsp[-2].unit));(yyval.unit)=(yyvsp[-2].unit);}
-#line 1549 "parse.tab.c" /* yacc.c:1646  */
+#line 1553 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 15:
-#line 229 "parse.y" /* yacc.c:1646  */
+#line 229 "parse.y" /* yacc.c:1652  */
     { (yyval.number) = (yyvsp[0].number);         }
-#line 1555 "parse.tab.c" /* yacc.c:1646  */
+#line 1559 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 16:
-#line 230 "parse.y" /* yacc.c:1646  */
+#line 230 "parse.y" /* yacc.c:1652  */
     { (yyval.number) = (yyvsp[-2].number) / (yyvsp[0].number);    }
-#line 1561 "parse.tab.c" /* yacc.c:1646  */
+#line 1565 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 17:
-#line 233 "parse.y" /* yacc.c:1646  */
+#line 233 "parse.y" /* yacc.c:1652  */
     { (yyval.unit) = (yyvsp[-1].unit);  }
-#line 1567 "parse.tab.c" /* yacc.c:1646  */
+#line 1571 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 18:
-#line 239 "parse.y" /* yacc.c:1646  */
+#line 239 "parse.y" /* yacc.c:1652  */
     { (yyval.unit) = makenumunit((yyvsp[0].number),&err); CHECK(0);}
-#line 1573 "parse.tab.c" /* yacc.c:1646  */
+#line 1577 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 19:
-#line 240 "parse.y" /* yacc.c:1646  */
+#line 240 "parse.y" /* yacc.c:1652  */
     { (yyval.unit) = (yyvsp[0].unit); }
-#line 1579 "parse.tab.c" /* yacc.c:1646  */
+#line 1583 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 20:
-#line 241 "parse.y" /* yacc.c:1646  */
+#line 241 "parse.y" /* yacc.c:1652  */
     { err = unitpower((yyvsp[-2].unit),(yyvsp[0].unit));destroyunit((yyvsp[0].unit));
                                      CHECK((yyvsp[-2].unit));(yyval.unit)=(yyvsp[-2].unit);}
-#line 1586 "parse.tab.c" /* yacc.c:1646  */
+#line 1590 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 21:
-#line 243 "parse.y" /* yacc.c:1646  */
+#line 243 "parse.y" /* yacc.c:1652  */
     { err = multunit((yyvsp[-2].unit),(yyvsp[0].unit)); destroyunit((yyvsp[0].unit));
                                      CHECK((yyvsp[-2].unit));(yyval.unit)=(yyvsp[-2].unit);}
-#line 1593 "parse.tab.c" /* yacc.c:1646  */
+#line 1597 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 22:
-#line 245 "parse.y" /* yacc.c:1646  */
+#line 245 "parse.y" /* yacc.c:1652  */
     { err = multunit((yyvsp[-1].unit),(yyvsp[0].unit)); destroyunit((yyvsp[0].unit));
                                      CHECK((yyvsp[-1].unit));(yyval.unit)=(yyvsp[-1].unit);}
-#line 1600 "parse.tab.c" /* yacc.c:1646  */
+#line 1604 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 23:
-#line 247 "parse.y" /* yacc.c:1646  */
+#line 247 "parse.y" /* yacc.c:1652  */
     { (yyval.unit)=(yyvsp[0].unit); }
-#line 1606 "parse.tab.c" /* yacc.c:1646  */
+#line 1610 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 24:
-#line 248 "parse.y" /* yacc.c:1646  */
+#line 248 "parse.y" /* yacc.c:1652  */
     { err = rootunit((yyvsp[0].unit),2); CHECK((yyvsp[0].unit)); (yyval.unit)=(yyvsp[0].unit);}
-#line 1612 "parse.tab.c" /* yacc.c:1646  */
+#line 1616 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 25:
-#line 249 "parse.y" /* yacc.c:1646  */
+#line 249 "parse.y" /* yacc.c:1652  */
     { err = rootunit((yyvsp[0].unit),3); CHECK((yyvsp[0].unit)); (yyval.unit)=(yyvsp[0].unit);}
-#line 1618 "parse.tab.c" /* yacc.c:1646  */
+#line 1622 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 26:
-#line 250 "parse.y" /* yacc.c:1646  */
+#line 250 "parse.y" /* yacc.c:1652  */
     { err = funcunit((yyvsp[0].unit),(yyvsp[-1].realfunc));CHECK((yyvsp[0].unit)); (yyval.unit)=(yyvsp[0].unit);}
-#line 1624 "parse.tab.c" /* yacc.c:1646  */
+#line 1628 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 27:
-#line 251 "parse.y" /* yacc.c:1646  */
+#line 251 "parse.y" /* yacc.c:1652  */
     { err = logunit((yyvsp[0].unit),(yyvsp[-1].integer)); CHECK((yyvsp[0].unit)); (yyval.unit)=(yyvsp[0].unit);}
-#line 1630 "parse.tab.c" /* yacc.c:1646  */
+#line 1634 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 28:
-#line 252 "parse.y" /* yacc.c:1646  */
+#line 252 "parse.y" /* yacc.c:1652  */
     { err = evalfunc((yyvsp[0].unit),(yyvsp[-1].unitfunc),0,0); CHECK((yyvsp[0].unit));(yyval.unit)=(yyvsp[0].unit);}
-#line 1636 "parse.tab.c" /* yacc.c:1646  */
+#line 1640 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 29:
-#line 253 "parse.y" /* yacc.c:1646  */
+#line 253 "parse.y" /* yacc.c:1652  */
     { err = evalfunc((yyvsp[0].unit),(yyvsp[-1].unitfunc),1,0); CHECK((yyvsp[0].unit));(yyval.unit)=(yyvsp[0].unit);}
-#line 1642 "parse.tab.c" /* yacc.c:1646  */
+#line 1646 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 30:
-#line 255 "parse.y" /* yacc.c:1646  */
+#line 255 "parse.y" /* yacc.c:1652  */
     { (yyvsp[0].unit)->factor *= -1; err = unitpower((yyvsp[-3].unit),(yyvsp[0].unit));
                                      destroyunit((yyvsp[0].unit));CHECK((yyvsp[-3].unit));(yyval.unit)=(yyvsp[-3].unit);}
-#line 1649 "parse.tab.c" /* yacc.c:1646  */
+#line 1653 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 31:
-#line 258 "parse.y" /* yacc.c:1646  */
+#line 258 "parse.y" /* yacc.c:1652  */
     { (yyvsp[0].unit)->factor *= -1; err = unitpower((yyvsp[-3].unit),(yyvsp[0].unit));
                                      destroyunit((yyvsp[0].unit));CHECK((yyvsp[-3].unit));(yyval.unit)=(yyvsp[-3].unit);}
-#line 1656 "parse.tab.c" /* yacc.c:1646  */
+#line 1660 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 32:
-#line 260 "parse.y" /* yacc.c:1646  */
+#line 260 "parse.y" /* yacc.c:1652  */
     { err = E_BADNUM;   CHECK(0); }
-#line 1662 "parse.tab.c" /* yacc.c:1646  */
+#line 1666 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 33:
-#line 261 "parse.y" /* yacc.c:1646  */
+#line 261 "parse.y" /* yacc.c:1652  */
     { err = E_PARSEMEM; CHECK(0); }
-#line 1668 "parse.tab.c" /* yacc.c:1646  */
+#line 1672 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 34:
-#line 262 "parse.y" /* yacc.c:1646  */
+#line 262 "parse.y" /* yacc.c:1652  */
     { err = E_UNITEND;  CHECK(0); }
-#line 1674 "parse.tab.c" /* yacc.c:1646  */
+#line 1678 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 35:
-#line 263 "parse.y" /* yacc.c:1646  */
+#line 263 "parse.y" /* yacc.c:1652  */
     { err = E_LASTUNSET;CHECK(0); }
-#line 1680 "parse.tab.c" /* yacc.c:1646  */
+#line 1684 "parse.tab.c" /* yacc.c:1652  */
     break;
 
   case 36:
-#line 264 "parse.y" /* yacc.c:1646  */
+#line 264 "parse.y" /* yacc.c:1652  */
     { err = E_NOTAFUNC; CHECK((yyvsp[0].unit));}
-#line 1686 "parse.tab.c" /* yacc.c:1646  */
+#line 1690 "parse.tab.c" /* yacc.c:1652  */
     break;
 
 
-#line 1690 "parse.tab.c" /* yacc.c:1646  */
+#line 1694 "parse.tab.c" /* yacc.c:1652  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1711,14 +1715,13 @@ yyreduce:
   /* Now 'shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
-
-  yyn = yyr1[yyn];
-
-  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
-  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
-    yystate = yytable[yystate];
-  else
-    yystate = yydefgoto[yyn - YYNTOKENS];
+  {
+    const int yylhs = yyr1[yyn] - YYNTOKENS;
+    const int yyi = yypgoto[yylhs] + *yyssp;
+    yystate = (0 <= yyi && yyi <= YYLAST && yycheck[yyi] == *yyssp
+               ? yytable[yyi]
+               : yydefgoto[yylhs]);
+  }
 
   goto yynewstate;
 
@@ -1801,12 +1804,10 @@ yyerrlab:
 | yyerrorlab -- error raised explicitly by YYERROR.  |
 `---------------------------------------------------*/
 yyerrorlab:
-
-  /* Pacify compilers like GCC when the user code never invokes
-     YYERROR and the label yyerrorlab therefore never appears in user
-     code.  */
-  if (/*CONSTCOND*/ 0)
-     goto yyerrorlab;
+  /* Pacify compilers when the user code never invokes YYERROR and the
+     label yyerrorlab therefore never appears in user code.  */
+  if (0)
+    YYERROR;
 
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
@@ -1868,6 +1869,7 @@ yyacceptlab:
   yyresult = 0;
   goto yyreturn;
 
+
 /*-----------------------------------.
 | yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
@@ -1875,6 +1877,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
+
 #if !defined yyoverflow || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
@@ -1885,6 +1888,10 @@ yyexhaustedlab:
   /* Fall through.  */
 #endif
 
+
+/*-----------------------------------------------------.
+| yyreturn -- parsing is finished, return the result.  |
+`-----------------------------------------------------*/
 yyreturn:
   if (yychar != YYEMPTY)
     {
@@ -1914,7 +1921,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 267 "parse.y" /* yacc.c:1906  */
+#line 267 "parse.y" /* yacc.c:1918  */
 
 
 struct function 
